******************************
azure_devops_artifacts_helpers
******************************


.. image:: https://img.shields.io/github/license/djpugh/azure_devops_artifacts_helpers.svg
    :target: https://github.com/djpugh/azure_devops_artifacts_helpers/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/azure_devops_artifacts_helpers?style=flat-square
    :target: https://pypi.org/project/azure_devops_artifacts_helpers

.. image:: https://img.shields.io/pypi/implementation/azure_devops_artifacts_helpers?style=flat-square
    :target: https://pypi.org/project/azure_devops_artifacts_helpers

.. image:: https://img.shields.io/pypi/pyversions/azure_devops_artifacts_helpers?style=flat-square
    :target: https://pypi.org/project/azure_devops_artifacts_helpers

.. image:: https://img.shields.io/pypi/dm/azure_devops_artifacts_helpers?style=flat-square
    :target: https://pypistats.org/packages/azure_devops_artifacts_helpers

.. image:: https://img.shields.io/pypi/l/azure_devops_artifacts_helpers?style=flat-square
    :target: https://opensource.org/licenses/MIT

.. image:: https://github.com/djpugh/azure_devops_artifacts_helpers/workflows/Pipeline/badge.svg?branch=master&event=push
    :target: https://github.com/djpugh/azure_devops_artifacts_helpers/actions?query=workflow%3APipeline

.. image:: https://codecov.io/gh/djpugh/azure_devops_artifacts_helpers/branch/master/graph/badge.svg?token=APZ8YDJ0UD
    :target: https://codecov.io/gh/djpugh/azure_devops_artifacts_helpers

.. image:: https://app.fossa.com/api/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Fazure_devops_artifacts_helpers.svg?type=shield
    :target: https://app.fossa.com/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Fazure_devops_artifacts_helpers?ref=badge_shield

.. image:: https://sonarcloud.io/api/project_badges/measure?project=djpugh_azure_devops_artifacts_helpers&metric=alert_status
    :target: https://sonarcloud.io/dashboard?id=djpugh_azure_devops_artifacts_helpers

.. image:: https://img.shields.io/github/issues/djpugh/azure_devops_artifacts_helpers
    :target: https://github.com/djpugh/azure_devops_artifacts_helpers/issues

.. image:: https://img.shields.io/github/issues-pr-raw/djpugh/azure_devops_artifacts_helpers
    :target: https://github.com/djpugh/azure_devops_artifacts_helpers/pulls


Summary
~~~~~~~

Install using ``pip install azure_devops_artifacts_helpers``

Then use ``virtualenv <target_dir> --seeder azdo-pip``

To create a virtualenv with the ``artifacts-keyring`` package installed.

This also includes an extension for ``tox``, which will activate automatically (may require configuring
``requires`` in the ``tox`` config)

Links
~~~~~

* `Full Documentation <https://djpugh.github.io/azure_devops_artifacts_helpers>`_
* `Installation <https://djpugh.github.io/azure_devops_artifacts_helpers/installation.html>`_
* `Changelog <https://djpugh.github.io/azure_devops_artifacts_helpers/changelog.html>`_
* `Issues <https://github.com/djpugh/azure_devops_artifacts_helpers/issues>`_
* `PyPI <https://pypi.org/project/azure_devops_artifacts_helpers>`_
* |github| `Github <https://github.com/djpugh/azure_devops_artifacts_helpers>`_

.. |github| image:: https://api.iconify.design/logos-github-icon.svg
    :target: https://github.com/djpugh/azure_devops_artifacts_helpers

Coverage
~~~~~~~~

.. image:: https://codecov.io/gh/djpugh/azure_devops_artifacts_helpers/branch/master/graphs/sunburst.svg?token=APZ8YDJ0UD
    :target: https://codecov.io/gh/djpugh/azure_devops_artifacts_helpers

License Analysis
~~~~~~~~~~~~~~~~

.. image:: https://app.fossa.com/api/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Fazure_devops_artifacts_helpers.svg?type=large
    :target: https://app.fossa.com/projects/custom%2B20832%2Fgithub.com%2Fdjpugh%2Fazure_devops_artifacts_helpers?ref=badge_shield

---------------------------

(Built from `package-template <https://github.com/djpugh/package-template>`_ version 1.0.0)